@@ -79,44 +79,40 @@ sub remove_attribute  { delete $_[0]->{attributes}->{$_[1]} }
 
 sub get_attribute_list{ keys   %{$_[0]->{attributes}} }
 
-# XXX: for backward compatibility
+# XXX: not completely compatible with Moose
 my %foreign = map{ $_ => undef } qw(
     Mouse Mouse::Role Mouse::Util Mouse::Util::TypeConstraints
     Carp Scalar::Util List::Util
 );
-sub _code_is_mine{
-#    my($self, $code) = @_;
-
-    return !exists $foreign{ Mouse::Util::get_code_package($_[1]) };
+sub _get_method_body {
+    my($self, $method_name) = @_;
+    my $code = Mouse::Util::get_code_ref($self->{package}, $method_name);
+    return $code && !exists $foreign{ Mouse::Util::get_code_package($code) }
+        ? $code
+        : undef;
 }
 
 sub add_method;
 
 sub has_method {
     my($self, $method_name) = @_;
-
     defined($method_name)
         or $self->throw_error('You must define a method name');
 
-    return defined($self->{methods}{$method_name}) || do{
-        my $code = Mouse::Util::get_code_ref($self->{package}, $method_name);
-        $code && $self->_code_is_mine($code);
-    };
+    return defined( $self->{methods}{$method_name} )
+        || defined( $self->_get_method_body($method_name) );
 }
 
 sub get_method_body {
     my($self, $method_name) = @_;
-
     defined($method_name)
         or $self->throw_error('You must define a method name');
 
-    return $self->{methods}{$method_name} ||= do{
-        my $code = Mouse::Util::get_code_ref($self->{package}, $method_name);
-        $code && $self->_code_is_mine($code) ? $code : undef;
-    };
+    return $self->{methods}{$method_name}
+        ||= $self->_get_method_body($method_name);
 }
 
-sub get_method{
+sub get_method {
     my($self, $method_name) = @_;
 
     if(my $code = $self->get_method_body($method_name)){
@@ -319,7 +315,7 @@ Mouse::Meta::Module - The common base class of Mouse::Meta::Class and Mouse::Met
 
 =head1 VERSION
 
-This document describes Mouse version 0.76
+This document describes Mouse version 0.77
 
 =head1 DESCRIPTION
 
