@@ -1,13 +1,6 @@
 package Mouse::Object;
 use Mouse::Util qw(does dump meta); # enables strict and warnings
-
-sub new;
-sub BUILDARGS;
-sub BUILDALL;
-
-sub DESTROY;
-sub DEMOLISHALL;
-
+# all the stuff are defined in XS or PP
 1;
 __END__
 
@@ -17,57 +10,52 @@ Mouse::Object - The base object for Mouse classes
 
 =head1 VERSION
 
-This document describes Mouse version 0.76
+This document describes Mouse version 0.77
 
 =head1 METHODS
 
-=head2 C<< new (Arguments) -> Object >>
+=head2 C<< $class->new(%args | \%args) -> Object >>
 
 Instantiates a new C<Mouse::Object>. This is obviously intended for subclasses.
 
-=head2 C<< BUILDARGS (Arguments) -> HashRef >>
+=head2 C<< $class->BUILDARGS(@args) -> HashRef >>
 
-Lets you override the arguments that C<new> takes. Return a hashref of
-parameters.
+Lets you override the arguments that C<new> takes.
+It must return a HashRef of parameters.
 
-=head2 C<< BUILDALL (\%args) >>
+=head2 C<< $object->BUILDALL(\%args) >>
 
 Calls C<BUILD> on each class in the class hierarchy. This is called at the
 end of C<new>.
 
-=head2 C<< BUILD (\%args) >>
+=head2 C<< $object->BUILD(\%args) >>
 
 You may put any business logic initialization in BUILD methods. You don't
 need to redispatch or return any specific value.
 
-=head2 C<< DEMOLISHALL >>
+=head2 C<< $object->DEMOLISHALL >>
 
 Calls C<DEMOLISH> on each class in the class hierarchy. This is called at
 C<DESTROY> time.
 
-=head2 C<< DEMOLISH >>
+=head2 C<< $object->DEMOLISH >>
 
 You may put any business logic deinitialization in DEMOLISH methods. You don't
 need to redispatch or return any specific value.
 
-
-=head2 C<< does ($role_name) -> Bool >>
+=head2 C<< $object->does($role_name) -> Bool >>
 
 This will check if the invocant's class B<does> a given C<$role_name>.
-This is similar to "isa" for object, but it checks the roles instead.
+This is similar to C<isa> for object, but it checks the roles instead.
 
-=head2 C<< dump ($maxdepth) -> Str >>
+=head2 C<< $object->dump($maxdepth) -> Str >>
 
-From the Moose POD:
+This is a handy utility for dumping an object with Data::Dumper.
+By default, the maximum depth is 3, to avoid making a mess.
 
-    C'mon, how many times have you written the following code while debugging:
+=head2 C<< $object->meta() -> MetaClass >>
 
-     use Data::Dumper; 
-     warn Dumper $obj;
-
-    It can get seriously annoying, so why not just use this.
-
-The implementation was lifted directly from Moose::Object.
+This is a method which provides access to the object's metaclass.
 
 =head1 SEE ALSO
 
